#
# spec file for package libmediainfo
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016 Packman Team <packman@links2linux.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover	0
Name:           libmediainfo
Version:        0.7.96
Release:        2.3.1
Summary:        Supplies technical and tag information about a video or audio file
License:        BSD-2-Clause
Group:          Development/Libraries/C and C++
URL:            http://mediainfo.sourceforge.net/
Source:         https://sourceforge.net/projects/mediainfo/files/source/libmediainfo/%{version}/libmediainfo_%{version}.tar.xz
Source1:        baselibs.conf
# PATCH-FIX-UPSTREAM CVE-2019-11372_CVE-2019-11373.patch
Patch0:         CVE-2019-11372_CVE-2019-11373.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libcurl-devel
BuildRequires:  libmms-devel
BuildRequires:  libtool
BuildRequires:  libzen-devel >= 0.4.31
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
MediaInfo supplies technical and tag information about a video or
audio file.

%package -n %{name}%{sover}
Summary:        Supplies technical and tag information about a video or audio file
Group:          System/Libraries

%description -n %{name}%{sover}
MediaInfo supplies technical and tag information about a video or
audio file.

What information can I get from MediaInfo?
* General: title, author, director, album, track number, date, duration...
* Video: codec, aspect, fps, bitrate...
* Audio: codec, sample rate, channels, language, bitrate...
* Text: language of subtitle
* Chapters: number of chapters, list of chapters

DivX, XviD, H263, H.263, H264, x264, ASP, AVC, iTunes, MPEG-1,
MPEG1, MPEG-2, MPEG2, MPEG-4, MPEG4, MP4, M4A, M4V, QuickTime,
RealVideo, RealAudio, RA, RM, MSMPEG4v1, MSMPEG4v2, MSMPEG4v3,
VOB, DVD, WMA, VMW, ASF, 3GP, 3GPP, 3GP2

What format (container) does MediaInfo support?
* Video: MKV, OGM, AVI, DivX, WMV, QuickTime, Real, MPEG-1,
  MPEG-2, MPEG-4, DVD (VOB) (Codecs: DivX, XviD, MSMPEG4, ASP,
  H.264, AVC...)
* Audio: OGG, MP3, WAV, RA, AC3, DTS, AAC, M4A, AU, AIFF
* Subtitles: SRT, SSA, ASS, SAMI

This package contains the shared library for MediaInfo(-gui).

%package -n libmediainfo-devel
Summary:        Include files and libraries for development
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}
Requires:       glibc-devel
Requires:       libcurl-devel
Requires:       libmms-devel
Requires:       zlib-devel

%description -n libmediainfo-devel
Include files and mandatory libraries for development.

%prep
%setup -q -n MediaInfoLib
%patch0 -p1
cp Release/ReadMe_DLL_Linux.txt \
    ReadMe.txt
mv History_DLL.txt \
    History.txt

sed -i 's/\r$//' *.txt *.html Source/Doc/Documentation.html
chmod 644 *.txt *.html Source/Doc/Documentation.html

%build
# generate docs
pushd Source/Doc
    doxygen -u 2> /dev/null
    doxygen Doxyfile
popd

export CFLAGS="%{optflags} -I%{_includedir}/libmms"
export CPPFLAGS="%{optflags} -I%{_includedir}/libmms"
export CXXFLAGS="%{optflags} -I%{_includedir}/libmms"

pushd Project/GNU/Library
    chmod +x autogen.sh
    ./autogen.sh
    %configure \
    	--enable-shared \
    	--disable-static \
    	--with-libcurl \
    	--with-libmms=%{_libdir}

    make %{?_smp_mflags}
popd

%install
pushd Project/GNU/Library/
%make_install
popd

# MediaInfoDLL headers and MediaInfo-config
for i in MediaInfo MediaInfoDLL; do
    install -dm 755 %{buildroot}%{_includedir}/$i
    install -m 644 Source/$i/*.h \
    	%{buildroot}%{_includedir}/$i
done

install -m 644 Source/MediaInfoDLL/MediaInfoDLL.cs \
    %{buildroot}%{_includedir}/MediaInfoDLL
install -m 644 Source/MediaInfoDLL/MediaInfoDLL.JNA.java \
    %{buildroot}%{_includedir}/MediaInfoDLL
install -m 644 Source/MediaInfoDLL/MediaInfoDLL.JNative.java \
    %{buildroot}%{_includedir}/MediaInfoDLL
install -m 644 Source/MediaInfoDLL/MediaInfoDLL.py \
    %{buildroot}%{_includedir}/MediaInfoDLL
install -m 644 Source/MediaInfoDLL/MediaInfoDLL3.py \
    %{buildroot}%{_includedir}/MediaInfoDLL

sed -i -e 's|Version: |Version: %{version}|g' \
    Project/GNU/Library/libmediainfo.pc
install -dm 755 %{buildroot}%{_libdir}/pkgconfig
install -m 644 Project/GNU/Library/libmediainfo.pc \
    %{buildroot}%{_libdir}/pkgconfig

rm Doc/installdox || true
rm %{buildroot}%{_libdir}/libmediainfo.la
%fdupes -s %{buildroot}/%{_datadir}

%post   -n libmediainfo%{sover} -p /sbin/ldconfig
%postun -n libmediainfo%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%defattr(-,root,root,-)
%doc History.txt License.html ReadMe.txt
%{_libdir}/libmediainfo.so.%{sover}
%{_libdir}/libmediainfo.so.%{sover}.*

%files -n libmediainfo-devel
%defattr(-,root,root,-)
%doc Changes.txt Source/Doc/Documentation.html
%doc Doc/*
%{_includedir}/MediaInfo/
%{_includedir}/MediaInfoDLL/
%{_libdir}/libmediainfo.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Apr 23 2019 aloisio@gmx.com
- Added CVE-2019-11372_CVE-2019-11373.patch
  * fixes bsc#1133156 (CVE-2019-11373)
  * fixes bsc#1133157 (CVE-2019-11372)
* Thu Jun  1 2017 aloisio@gmx.com
- Update to version 0.7.96
  * MPEG-4: display of recorded date from DV substream
  * I505, AC-3: crash with some potentially malformed frames
  * I477, AVC: fix hang when open .mpls from some 3D BD
  * MPEG-4: does not show "1904" year is raw value is 0 (Mac/Linux)
  * Dedicated read thread disabled by default (rare dead locks)
  * #B1027, MPEG-TS: some files where detected as MPEG-TS or BDAV
    but they aren't
  * Sequence of files : frame count was wrong with sequence of
    MPEG-TS files (was count of files)
  * MXF: detection of more 608/708 with parsing of few frames in the
    middle of the file was broken
* Fri May  5 2017 aloisio@gmx.com
- Update to version 0.7.95
  * EBUCore: EBUCore 1.8 with acquisition metadata output.
  * Better support of growing files, especially when accessed by FTP
  * Matroska: better support of some broken files (high
    EBMLMaxSizeLength, padding before start of EBML)
  * EXR: showing Multipart and Deep flags
  * EXR: show image compression method
  * EBUCore: fixed display aspect ratio (was using rational)
  * EBUCore: fixed frame rate factor (was num/den instead of factor)
  * AVC: some streams with dynamic frame type were having a wrong
    frame rate
  * MPEG-4: some old AAC tracks were not correctly detected
  * Matroska: was sometimes displaying "Bit depth: Bit0" when bit
    depth is unknown
  * Nut: fix crash with some files
  * FFV1: PixelAspectRatio was an integer, switched to 3-digit
    rational
  * DTS: fix frame count
  * Dolby E: fix frame count
  * EBUCore: fix regression creating invalid XML files
  * AVC: some streams with dynamic frame type were having a wrong
    frame rate
  * I490, EXR: was not supporting valid 31-char attribute names
* Thu Mar 30 2017 aloisio@gmx.com
- Update to version 0.7.94
  * VC-3: detection of embedded time code + VC-3: better
    support of stream with width 960 or 1440
  * VC-3: support of version 3 (a.k.a. DNxHR), including
    profile and level for version 1/2 (a.k.a. DNxHD)
  * Matroska trace feature: reduction of its size
  * MXF trace feature: reduction of its size
  * M143, MXF with Acquisition Metadata: crash fixed
  * Several crash fixes
  0.7.94
  * Matroska: detection of native FFV1 CodecID ("V_FFV1") +
    AC-3/E-AC-3: detection of Atmos inside core streams
  * AC-3/E-AC-3: slight reorganization of metadata display for
    dual mono and surround
  * AC-3/E-AC-3: "complete main" and similar info moved to
    "Service kind" dedicated line
  * AC-3/E-AC-3: more precision about how is built a stream
    (e.g. "E-AC-3+Atmos / E-AC-3" or "TrueHD+Atmos / TrueHD /
    AC-3")
  * WTV: basic detection
  * MPEG-TS: Detection of Opus
  * URL: "URLEncode" option for saying if the input should be
    URL encoded or not (default is guess = no change except if
    it contains spaces)
  * MediaTrace: for bitstreams (not bytestreams), bit offset
    was wrong
  * HLS: duration was sometimes wrong, reading only the first
    TS file duration. Now full duration is displayed
  * MPEG-TS: if stream is encrypted or invalid, level was
    sometimes not the expected one for AVC (e.g. "BaseLine@3.0"
    instead of "Baseline@3")
  * Matroska: FFV1 stream width/height was not initialized
    when Matroska track header width/height is after CodecID
  * FFV1: fix potential crash with some buggy slice headers
  * Matroska: crash in case of big attachment and CRC32 present
* Thu Mar 16 2017 aloisio@gmx.com
- Removed redundant requires from devel package
* Fri Mar 10 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflects its use
- RPM group correction
* Sun Feb 26 2017 aloisio@gmx.com
- Added baselibs.conf as source file
* Sun Feb 26 2017 aloisio@gmx.com
- Update to version 0.7.92.1
  * Fix a performance regression in the matroska parser
  version 0.7.92
  New features:
  * #F507, MXF: detection of HLG Transfer Characteristic
  * #F508, HEVC: support of preferred_transfer_characteristics
    SEI (from HEVC/H.265 draft, preferred method for HLG in DVB)
  * MXF: parsing of AVC descriptors and crosscheck with the
    essence content
  * MP4: more AppleStoreCountry values mapped to countries,
    show the country number if unknown
  * File extension: test if the file extension correspond to
    the container format
  * AVI/WAV: test of truncated file
  * MIXML output: Format_Profile divided in Format_Profile,
    Format_Level, Format_Tier
  * ID3v2: TCAP tag is mapped to new field "PodcastCategory"
  Bug fixes:
  * MIXML output: some *_Original values were missing
  * MXF/Teletext: was not correctly detecting non subtitle
    streams
  * ID3v2: TP2 tag was incorrectly mapped to "Accompaniment",
    now mapped to "Album_Performer"
  * ID3v2: TSO2 tag was incorrectly mapped to
    "Performer_Sort", now mapped to "Album_Performer_Sort"
  * ID3v2: TCMP tag was displayed twice (2 "Compilation" lines)
  version 0.7.91
  New features:
  * IMF and PTX: more languages detected from file names (but
    the full list of common languages tags still need to be
    added)
  * IMF and PTX: support of non-standard but common "LAS" =
    "Spanish (Latin America)" language code
  * MXF: Support of color primaries, transfer characteristic,
    coding equations defined in SMPTE ST 2067-21:2016 e.g. xvYCC
    or BT.2020
  * Minor performance optimizations and cleanup (Thanks to
    Pavel Pimenov)
  * MediaTrace optimization for Matroska
  Bug fixes:
  * Fixed parsing of FFV1 v0/v1
  * PTX: fix crash due to bad parsing of some file names while
    looking for track language
  version 0.7.90
  New features:
  * #M94, WAV: support of file with a buggy RIFF header
  * Matroska: detection of segment size of zero (compatibility
    risks e.g. Windows 10 Media Player does not play such file)
  * MXF: detection of some incoherences between header and
    footer
  * MXF: display of Locked information
  * N19/STL: support of 48/50/60 fps content
  * N19/STL: display of time code of first frame
  * AC-3: bit depth
  * MPEG Video: CBR bitrate mode information based on vbv_delay
  * DXW: support of fake time code attribute
  Bug fixes:
  * Teletext in MPEG-TS: CodecID, format (classic teletext or
    subtitle), video delay were sometimes not displayed
  * PDF: fixed crash with some files with full analysis set
  * #B485, BMP height is negative
  * Several minor fixes
- Converted libmediainfo.changes to unix format
- Set correct license
* Thu Oct  6 2016 aloisio@gmx.com
- Update to version 0.7.89
  * I changed some elements in the interface.
    No break in binary compatibily (no crash), but some
    details.
  0.7.79 --> 0.7.80
  * Visual Basic binding: StreamKind.Visual changed to
    StreamKind.Video for more coherency with other bindings
    (StreamKind.Visual is still available but it is deprecated)
  0.7.73 --> 0.7.74
  * EBUCore: Source/Material moved from timecodeStart to
  timecodeTrack
  * AES3: generic term AES3 replaced by more precise SMPTE
    ST numbers (302, 331, 337)
  0.7.72 --> 0.7.73
  * Clean aperture size is move from width/height to its own
    field
  * HEVC: format_Profile field changed from Profile@Level to
    Profile@Level@Tier
  * MXF: writing library and writing application fields are
    cleaned up, you may face some incompatibility or different
    values
  * AVC and HEVC: Level x.0 are replaced by Level x, because
    specs have no .0
  0.7.71 --> 0.7.72
  * EBUCore 1.5 output is slighly modified, check the
    compatibility with your workflow
  * PBCore2: codecid changed
  0.7.70 --> 0.7.71
  * Time code striped/not striped information is moved from
    "Format_Settings" to "TimeCode_Striped"
  0.7.69 --> 0.7.70
  * BitDepth: for very rare MXF containing PCM having
    quantization bits not same as stored bit depth, Stored bit
    depth has moved from "BitDepth" to "BitDepth_Stored".
    "BitDepth is the quantization bits value.
- Spec cleanup
* Thu Mar 27 2014 i@margueirte.su
- update version 0.7.67
  * MXF: duplicate display of some time code streams in ancillary data
  * B814, AAC: Wrong detection of audioObjectType==29
* Thu Feb 28 2013 fisiu@opensuse.org
- update to 0.7.62 (changes since 0.7.60):
  * MOV "menu" moved to "other", for better separation of time code tracks
  * "Intermediate Codec" is renamed to "AIC" (Apple Intermediate Codec)
  * MPEG-TS: Menu stream, KLVA_PID and SCTE35_PID removed and formats are in "Format" field
  * DTS: moved DTS endianess and word size
* Thu Oct  4 2012 i@marguerite.su
- update to 0.7.60
  * MPEG-TS/PS: improved detection of buggy time stamps
  * DPX: color primaries and transfer characteristics
  * MPEG-TS: Added support of scrambled streams without transport_scrambling_control bit set (e.g. PlayReady)
  * MPEG-TS: Name of some scrambling algorithms
  * MPEG-TS: detection of CBR/VBR at container level
  * MPEG Video: better detection of variable GOP
  * MPEG-TS: average, minimum, maximum PCR distance (hidden by default and you must parse the whole file with --ParseSpeed=1 option)
  * Matroska: some streams were wrongly detected sa VFR
  * #3538378, XML output: invalid characters, now if there is an invalid character, data is transported in base64
  * LXF: wrong video bit rate with some files
  * AC-3/E-AC-3: hang up with some Little Endian streams
  * AAC: wrong min and max bit rate in case of partial (default) parsing, disabling it
  * AVC: crash or hang up with some malformed/scrambled streams
  * Opus: wrong duration in case of non-48kHz stream
  * MOV: 25 fps + drop frame time codes were not handled correctly
* Sat May 19 2012 seife+obs@b1-systems.com
- add autoconf/automake/libtool to buildreq to fix 12.2 build
* Sat Jul 31 2010 toni@links2linux.de
- update to 0.7.34
* Mon May  3 2010 toni@links2linux.de
- update to 0.7.32
* Fri Apr 16 2010 toni@links2linux.de
- update to 0.7.31
* Fri Mar 26 2010 toni@links2linux.de
- update to 0.7.30
* Tue Mar  9 2010 toni@links2linux.de
- update to 0.7.29
* Sun Feb 21 2010 toni@links2linux.de
- update to 0.7.28
* Mon Jan 11 2010 toni@links2linux.de
- update to 0.7.27
* Wed Dec 23 2009 toni@links2linux.de
- update to 0.7.26
* Fri Nov 20 2009 toni@links2linux.de
- update to 0.7.25
* Fri Oct 30 2009 toni@links2linux.de
- update to 0.7.24
* Tue Oct 27 2009 toni@links2linux.de
- update to 0.7.23
* Tue Oct 13 2009 toni@links2linux.de
- update to 0.7.19
* Mon Jun 22 2009 toni@links2linux.de
- update to 0.7.17
* Wed May 20 2009 toni@links2linux.de
- update to 0.7.16
* Thu Apr 30 2009 toni@links2linux.de
- update to 0.7.15
* Fri Apr 17 2009 toni@links2linux.de
- update to 0.7.14
* Sun Apr  5 2009 toni@links2linux.de
- update to 0.7.13
* Sat Apr  4 2009 toni@links2linux.de
- redowngrade to 0.7.12
* Fri Apr  3 2009 toni@links2linux.de
- update to 0.7.13
* Fri Mar 20 2009 toni@links2linux.de
- update to 0.7.12
* Fri Feb 13 2009 toni@links2linux.de
- update to 0.7.11
* Fri Jan 30 2009 toni@links2linux.de
- update to 0.7.10
* Fri Jan 23 2009 toni@links2linux.de
- update to 0.7.9
* Tue Dec  9 2008 toni@links2linux.de
- update to 0.7.8
- docs are now generated with doxygen
* Wed Nov 19 2008 toni@links2linux.de
- rebuild with modified sources from author to fix gui problem
* Mon Nov 17 2008 toni@links2linux.de
- update to 0.7.7.8
* Mon Dec 10 2007 toni@links2linux.de
- libZenLib and libMediaInfoLib are renamed to libzen and libmediainfo
- install *-config files manually
- added devel-subpackages
- split off from MediaInfo package
